@@ -1,6 +1,9 @@
-import sympy as sy
+import sympy
 import IPython
 
+from artemix.latemix import *
+#https://widdowquinn.github.io/coding/update-pypi-package/
+
 def Inicializar(n):
   global DatosList,Orden,Estilo
 
@@ -13,21 +16,26 @@ def Inicializar(n):
   elif n == 4:
     Estilo = "textit"#italic
 
-  DatosList = [[sy.pi,3.14]]
+  DatosList = [[sympy.pi,3.14]]
   Orden = 8
   return DatosList,Orden
 
-#def Busqueda(symbolo):
-#  for c_element in DatosList:
-#    if c_element[0] == symbolo:
-#      if c_element[1] != None:
-#        return c_element[1]
-#      else:
-#        return c_element[1]
+def Busqueda(symbolo):
+  for c_element in DatosList:
+    if c_element[0] == symbolo:
+      if isinstance(c_element[1],float):#Si tenemos un numero
+          return sympy.symbols(str(c_element[1]))
+      elif isinstance(c_element[1],int):#Si tenemos un float
+          return sympy.symbols(str(c_element[1]))
+      elif c_element[1] != None:#Si tenemos una expresión
+          return c_element[1]
+      else:
+        return c_element[1]#Si es None
+  return symbolo
 
 def Redondear(expr):#Redondeamos la expresión.
-  if isinstance(expr, sy.Expr) or isinstance(expr, sy.Float):
-    Aproximacion = expr.xreplace(sy.core.rules.Transform(lambda x: x.round(Orden), lambda x: isinstance(x, sy.Float)))
+  if isinstance(expr, sympy.Expr) or isinstance(expr, sympy.Float):
+    Aproximacion = expr.xreplace(sympy.core.rules.Transform(lambda x: x.round(Orden), lambda x: isinstance(x, sympy.Float)))
   elif isinstance(expr,float) or isinstance(expr,int):
     Aproximacion = round(expr,Orden)
   else:
@@ -38,7 +46,7 @@ def Redondear(expr):#Redondeamos la expresión.
 def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que es un derivado.
   print("")
   Tipo = None
-  if isinstance(elemento,sy.core.relational.Equality):#Si el elemento ingresado es una ecuación, entonces la identificamos
+  if isinstance(elemento,sympy.core.relational.Equality):#Si el elemento ingresado es una ecuación, entonces la identificamos
     Tipo = "Ecuacion"
   elif isinstance(elemento,list):#Si el elemento ingresado es un componente, entonces lo identificamos.
     Tipo = "Componente"
@@ -46,11 +54,11 @@ def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que
   
   if Tipo == "Ecuacion":#Si hemos identificado el elemento ingresado como una ecuación, entonces la imprimimos en rojo
 
-    a = sy.latex(elemento.args[0])
+    a = sympy.latex(elemento.args[0])
 
     b = "="
 
-    c = sy.latex(elemento.args[1])
+    c = sympy.latex(elemento.args[1])
 
     texto = a+b+c
     texto = texto.replace("text", Estilo)
@@ -59,21 +67,21 @@ def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que
 
   if Tipo == "Componente":#Si hemos identificado el elemento ingresado como un componente, entonces lo imprimimos en rojo
     if not isinstance(c_componente[0],str):#isinstance(c_componente[0],sy.core.symbol.Symbol) or isinstance(c_componente[0],sy.core.symbol.Symbol) :
-      a = sy.latex(c_componente[0])
+      a = sympy.latex(c_componente[0])
 
       b = " = "
 
-      c = sy.latex(Redondear(c_componente[1]))
+      c = sympy.latex(Redondear(c_componente[1]))
 
       texto = a + b + c
       texto = texto.replace("text", Estilo)
       IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
     elif isinstance(c_componente[0],str):
-      a = sy.latex(c_componente[0])
+      a = sympy.latex(c_componente[0])
       
       b = " = "
 
-      c = sy.latex(Redondear(c_componente[1]))
+      c = sympy.latex(Redondear(c_componente[1]))
 
       texto = a + b + c
       texto = texto.replace("text", Estilo)
@@ -86,32 +94,32 @@ def E(expr,color = "red"):
   for element in DatosList:
     if (element[1] != None) :
       word = "" #if isinstance(element[1],sy.Float) or isinstance(element[1],float) or isinstance(element[1],int) or isinstance(element[1],sy.core.numbers.Integer):
-      for letra in sy.latex(Redondear(element[1])):
+      for letra in sympy.latex(Redondear(element[1])):
         if letra == " ":
           word = word+"~"
         else:
           word = word+letra
-      DataRealSymbolList.append([element[0],sy.symbols("("+word+")")])
+      DataRealSymbolList.append([element[0],sympy.symbols("("+word+")")])
     else:
       #Es decir, si es un simbolo sin valor (None) o coleccion de simbolos. Entonces:
       DataRealSymbolList.append([element[0],element[0]])
   #display(DataRealSymbolList)
 
 
-  if isinstance(expr,sy.core.relational.Equality):
-    texto = sy.latex(expr)
+  if isinstance(expr,sympy.core.relational.Equality):
+    texto = sympy.latex(expr)
     for element in DataRealSymbolList:
-      texto = texto.replace(sy.latex(element[0]), sy.latex(element[1]))
+      texto = texto.replace(sympy.latex(element[0]), sympy.latex(element[1]))
 
     #D(expr.subs(DataRealSymbolList))
     IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
   
   if isinstance(expr,list):
-    texto = sy.latex(expr[1])
+    texto = sympy.latex(expr[1])
     for element in DataRealSymbolList:
-      texto = texto.replace(sy.latex(element[0]), sy.latex(element[1]))
+      texto = texto.replace(sympy.latex(element[0]), sympy.latex(element[1]))
 
-    texto = sy.latex(expr[0]) +" = "+texto
+    texto = sympy.latex(expr[0]) +" = "+texto
     #D([expr[0],expr[1].subs(DataRealSymbolList)])
     IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
     #D([expr[0],sy.N(expr[1].subs(DatosList))])
@@ -152,6 +160,3 @@ def A(c_componente):#Actualizar
 def R(string):
   display(IPython.display.Latex(string))  
 
-from artemix.test import *
-hola()
-#https://widdowquinn.github.io/coding/update-pypi-package/
\ No newline at end of file
